﻿using Sharpex2D.Framework.Game;
using Sharpex2D.Framework.Math;
using Sharpex2D.Framework.Rendering;
using Sharpex2D.Framework.Rendering.Devices;
using Sharpex2D.Framework.Rendering.Fonts;

namespace FlyingBird.Misc
{
    public class Instructions
    {
        /// <summary>
        /// A value indicating whether the Instructions is visible.
        /// </summary>
        public bool Visible { set; get; }

        /// <summary>
        /// Renders the object.
        /// </summary>
        /// <param name="renderer">The Renderer.</param>
        public void Render(RenderDevice renderer)
        {
            if (!Visible) return;

            if (!InstructionFlag)
            {
                renderer.DrawTexture(_texture, _position, _opacity);
                var dim = renderer.MeasureString(Instruction, _font);
                renderer.DrawString(Instruction, _font, new Vector2(_position.X - dim.X/2 + 28, _position.Y - 30),
                    Color.White);
            }
            else
            {
                renderer.DrawTexture(_texture, _position, _opacity);
                var dim = renderer.MeasureString(Instruction2, _font);
                renderer.DrawString(Instruction2, _font, new Vector2(_position.X - dim.X / 2 + 28, _position.Y - 30),
                    Color.White);
            }
        }

        /// <summary>
        /// Updates the object.
        /// </summary>
        /// <param name="gameTime">The GameTime.</param>
        public void Update(GameTime gameTime)
        {
            if (!_flag)
            {
                _opacity -= 0.02f;
                if (_opacity <= 0)
                {
                    _flag = true;
                    _opacity = 0;
                }
            }
            else
            {
                _opacity += 0.02f;
                if (_opacity >= 1)
                {
                    _flag = false;
                    _opacity = 1;
                }
            }
        }

        /// <summary>
        /// Gets or sets the InstructionFlag.
        /// </summary>
        public bool InstructionFlag { set; get; }

        private readonly Texture2D _texture;
        private readonly Vector2 _position;
        private float _opacity = 1f;
        private bool _flag;
        private readonly Font _font;
        private const string Instruction = "TAP WITH YOUR MOUSE TO START THE GAME";
        private const string Instruction2 = "TAP WITH YOUR MOUSE TO RESET.";

        /// <summary>
        /// Initializes a new Instructions class.
        /// </summary>
        /// <param name="texture">The Texture.</param>
        public Instructions(Texture2D texture)
        {
            _texture = texture;
            _position = new Vector2(291, 215);
            _font = new Font("Segoe UI", 11, TypefaceStyle.Regular);
        }
    }
}
